#!/usr/bin/perl

# emvironment.
$JAVA="/usr/java/jdk1.3.1/bin/java";
$BLIB="./saxbench.jar";
$BCLASS="sax.SAXBench";
$JAVAOPT="";
$PS=":"; # path separator

# parser driver for SAXBench.
$SAX1="sax.SAX1Driver";
$SAX2="sax.SAX2Driver";
$JAXP="sax.JAXPDriver";
$TINY="sax.TinyXMLDriver";
$LARK="sax.LarkDriver";
$validation=0;
#### main
$parser = "";
if($#ARGV < 0) {
    &usage();
    exit();
}
if($ARGV[0] EQ "-name") {
    shift;
    $parser = $ARGV[0];
    shift;
}
if($ARGV[0] EQ "-J") {
    shift;
    $JAVAOPT = $ARGV[0];
    shift;
}
foreach(@ARGV) {
    if($_ EQ "-v") {
	$validation = 1;
    } elsif($_ EQ "-V") {
	$validation = 0;
    }
}
if($parser NE "") {
    &bench_one();
}else{
    &bench_all();
}

####
sub usage {
    print <<EOT
USAGE: runSAXBench.pl [-name 'parserName'] [SAXBench options...] filenames...
EOT
    ;
}
sub bench_all {
    &xerces();
    &crimson();
    &oracle();
    &xp();
    &aelfred();
    &nanoXML();
    &xml4j();
    &tinyXML();
    &lark();
    # minML & min can't eat normal XML inputs.
    #&minML();
    #&min();
}


sub bench_one {
    if($parser EQ "xerces") {
	&xerces();
    }elsif($parser EQ "xml4j") {
	&xml4j();
    }elsif($parser EQ "crimson") {
	&crimson();
    }elsif($parser EQ "oracle") {
	&oracle();
    }elsif($parser EQ "xp") {
	&xp();
    }elsif($parser EQ "aelfred") {
	&aelfred();
    }elsif($parser EQ "nanoxml") {
	&nanoXML();
    }elsif($parser EQ "minml") {
	&minML();
    }elsif($parser EQ "minml2") {
	&minML2();
    }elsif($parser EQ "min") {
	&min();
    }elsif($parser EQ "tinyxml") {
	&tinyXML();
    }elsif($parser EQ "tinyxmlsax") {
	&tinyXMLSAX();
    }elsif($parser EQ "lark") {
	&lark();
    }else{
	die "unknown parser '$parser'.";
    }
}

sub xerces {
    $MSG="Xerces-J 1.4.0";
    $LIB="/usr/local/xerces-1_4_0/xerces.jar";
    $CLASS="org.apache.xerces.parsers.SAXParser";
    $DRIVER=$SAX2;
    &bench();
}

sub xml4j {
    $MSG="XML4J 3.1.1";
    $LIB="./parsers/XML4J-3_1_1/xerces.jar$PS./parsers/XML4J-3_1_1/xml4j.jar";
    $CLASS="org.apache.xerces.parsers.SAXParser";
    $DRIVER=$SAX2;
    &bench();
}

sub oracle {
    $MSG="Oracle XML Parser 9.0.1.0.0 Production";
    $LIB="./parsers/OracleXDK/lib/xmlparserv2.jar";
    $CLASS="oracle.xml.parser.v2.SAXParser";
    $DRIVER=$JAXP;
    &bench();
}

sub xp {
    $MSG="XP 0.5";
    $LIB="./parsers/xp/xp.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="com.jclark.xml.sax.Driver";
    $DRIVER=$SAX1;
    &bench();
}

sub crimson {
    $MSG="Crimson 1.1 (JAXP1.1)";
    $LIB="./parsers/jaxp-1.1/crimson.jar$PS./parsers/jaxp-1.1/jaxp.jar";
    $CLASS="org.apache.crimson.parser.XMLReaderImpl";
    $DRIVER=$SAX2;
    &bench();
}

sub aelfred {
    $MSG="AElfred v2(2001/01/23 19:59:04)";
    $LIB="./parsers/aelfred2/xmlconf-utilities-20010124.jar";
    if($validation > 0) {
	$CLASS="xml.aelfred2.Validator";
    }else{
	$CLASS="xml.aelfred2.SAXDriver";
    }
    $DRIVER=$SAX2;
    &bench();
}

sub nanoXML {
    $MSG="NanoXML 1.6.8 (SAX)";
    $LIB="./parsers/NanoXML-1.6.8/nanoxml-sax.jar$PS./parsers/NanoXML-1.6.8/nanoxml.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="nanoxml.sax.SAXParser";
    $DRIVER=$SAX1;
    &bench();
}

sub minML {
    $MSG="MinML 1.3";
    $LIB="./parsers/MinML/MinML.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="uk.co.wilson.xml.MinML";
    $DRIVER=$SAX1;
    &bench();
}

sub minML2 {
    $MSG="MinML2 0.2";
    $LIB="./parsers/MinML2/MinML2.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="uk.co.wilson.xml.MinML2";
    $DRIVER=$SAX2;
    &bench();
}

sub min {
    $MSG="Min 1.0A5";
    $LIB="./parsers/minxml/minxml.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="com.docuverse.min.Parser";
    $DRIVER=$SAX1;
    &bench();
}

sub tinyXML {
    $MSG="TinyXML 0.7";
    $LIB="./parsers/TinyXML/tinyxml.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="gd.xml.XMLParser";
    $DRIVER=$TINY;
    &bench();
}

sub lark {
    $MSG="Lark 1.0 final beta";
    $LIB="./parsers/Lark/lark.jar$PS./parsers/xerces-1_4_0/xerces.jar";
    $CLASS="textuality.lark.Lark";
    $DRIVER=$LARK;
    &bench();
}

sub bench {
    system("echo");
    system("echo PARSER = '$MSG'");
    system("$JAVA $JAVAOPT -classpath $BLIB$PS$LIB $BCLASS -p $CLASS -d $DRIVER @ARGV");
}

